@@ -36,6 +36,19 @@ class CategoryAttributeDto:
     values: List[CategoryAttributeValueDto]
 
 
+@dataclass
+class AttributeValueDto:
+    remote_id: str
+    name: str
+
+
+@dataclass
+class AttributeDto:
+    remote_id: str
+    name: str
+    values: List[AttributeValueDto]
+
+
 @dataclass
 class CategoryDto:
     remote_id: str
